Function

Struct Function 

pub struct Function<'core> { /* private fields */ }
Holds a reference to a function that may be called.

Implementations

Source

impl<'core> Function<'core>

pub fn new<F>(_api: API, core: CoreRef<'core>, callback: F) -> Self
where F: Fn(API, CoreRef<'core>, &Map<'core>, &mut Map<'core>) + Send + Sync + 'core,

Creates a new function.

To indicate an error from the callback, set an error on the output map.

pub fn call(&self, in_: &Map<'core>, out: &mut Map<'core>)

Calls the function. If the call fails out will have an error set.